aboutsummaryrefslogtreecommitdiff
path: root/tests/unit/test_file_utils.py
diff options
context:
space:
mode:
authorBonfaceKilz2021-05-11 17:00:26 +0300
committerBonfaceKilz2021-05-13 11:18:57 +0300
commit378d0fc7f4ff5df5e8e77617c37bcef2b26ddf02 (patch)
tree59b6170f45c0857b0a7ba643e1746fdf5fc4c67a /tests/unit/test_file_utils.py
parent53f27b547e7220d46bdc2e92debb38a8739e511c (diff)
downloadgenenetwork3-378d0fc7f4ff5df5e8e77617c37bcef2b26ddf02.tar.gz
Rename file_utils to fs_helpers
Generally avoid naming things with a "utils" prefix/ suffix since it encourages contributors to dump any new functions there; and over time, as the code grows, things get messy...
Diffstat (limited to 'tests/unit/test_file_utils.py')
-rw-r--r--tests/unit/test_file_utils.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/tests/unit/test_file_utils.py b/tests/unit/test_file_utils.py
index cc842d5..75be4f6 100644
--- a/tests/unit/test_file_utils.py
+++ b/tests/unit/test_file_utils.py
@@ -1,14 +1,14 @@
"""Test cases for procedures defined in file_utils.py"""
import os
import unittest
from dataclasses import dataclass
from typing import Callable
from unittest import mock
-from gn3.file_utils import extract_uploaded_file
-from gn3.file_utils import get_dir_hash
-from gn3.file_utils import jsonfile_to_dict
-from gn3.file_utils import cache_ipfs_file
+from gn3.fs_helpers import extract_uploaded_file
+from gn3.fs_helpers import get_dir_hash
+from gn3.fs_helpers import jsonfile_to_dict
+from gn3.fs_helpers import cache_ipfs_file
@dataclass
@@ -19,7 +19,7 @@ class MockFile:
class TestFileUtils(unittest.TestCase):
"""Test cases for procedures defined in file_utils.py"""
def test_get_dir_hash(self):
"""Test that a directory is hashed correctly"""
@@ -45,8 +45,8 @@ non-existent"""
self.assertRaises(FileNotFoundError, jsonfile_to_dict,
"/non-existent-dir")
- @mock.patch("gn3.file_utils.tarfile")
- @mock.patch("gn3.file_utils.secure_filename")
+ @mock.patch("gn3.fs_helpers.tarfile")
+ @mock.patch("gn3.fs_helpers.secure_filename")
def test_extract_uploaded_file(self, mock_file, mock_tarfile):
"""Test that the gzip file is extracted to the right location"""
mock_file.return_value = "upload-data.tar.gz"
@@ -65,7 +65,7 @@ non-existent"""
mock_file.assert_called_once_with("upload-data.tar.gz")
self.assertEqual(result, {"status": 0, "token": "abcdef-abcdef"})
- @mock.patch("gn3.file_utils.secure_filename")
+ @mock.patch("gn3.fs_helpers.secure_filename")
def test_extract_uploaded_file_non_existent_gzip(self, mock_file):
"""Test that the right error message is returned when there is a problem
extracting the file"""
@@ -96,7 +96,7 @@ extracting the file"""
os.rmdir(test_dir)
self.assertEqual(file_loc, f"{test_dir}/genotype.txt")
- @mock.patch("gn3.file_utils.ipfshttpclient")
+ @mock.patch("gn3.fs_helpers.ipfshttpclient")
def test_cache_ipfs_file_cache_miss(self,
mock_ipfs):
"""Test that a file is cached if there's a cache miss"""
@@ -1,14 +1,14 @@
-"""Test cases for procedures defined in file_utils.py"""
+"""Test cases for procedures defined in fs_helpers.py"""
import os
import unittest
@@ -19,7 +19,7 @@ class MockFile:
class TestFileUtils(unittest.TestCase):
- """Test cases for procedures defined in file_utils.py"""
+ """Test cases for procedures defined in fs_helpers.py"""
def test_get_dir_hash(self):
"""Test that a directory is hashed correctly"""